@@ -19,7 +19,7 @@
 
 #include "rsync.h"
 
-int csum_length=SUM_LENGTH;
+int csum_length=2; /* initial value */
 
 #define CSUM_CHUNK 64
 
@@ -37,11 +37,12 @@ uint32 get_checksum1(char *buf,int len)
 
     s1 = s2 = 0;
     for (i = 0; i < (len-4); i+=4) {
-	s2 += 4*(s1 + buf[i]) + 3*buf[i+1] + 2*buf[i+2] + buf[i+3];
-	s1 += (buf[i+0] + buf[i+1] + buf[i+2] + buf[i+3]); 
+	s2 += 4*(s1 + buf[i]) + 3*buf[i+1] + 2*buf[i+2] + buf[i+3] + 
+	  10*CHAR_OFFSET;
+	s1 += (buf[i+0] + buf[i+1] + buf[i+2] + buf[i+3] + 4*CHAR_OFFSET); 
     }
     for (; i < len; i++) {
-	s1 += buf[i]; s2 += s1;
+	s1 += (buf[i]+CHAR_OFFSET); s2 += s1;
     }
     return (s1 & 0xffff) + (s2 << 16);
 }
