@@ -1,4 +1,4 @@
-/*	$Id: zlib.h,v 1.1 1996/07/03 04:05:49 paulus Exp $	*/
+/*	$Id: zlib.h,v 1.2 1996/10/02 04:20:23 paulus Exp $	*/
 
 /*
  * This file is derived from zlib.h and zconf.h from the zlib-0.95
@@ -444,8 +444,7 @@ extern int deflateInit2 OF((z_stream *strm,
                             int  method,
                             int  windowBits,
                             int  memLevel,
-                            int  strategy,
-			    int  minCompression));
+                            int  strategy));
 /*   
      This is another version of deflateInit with more compression options. The
    fields next_in, zalloc and zfree must be initialized before by the caller.
