@@ -123,28 +123,6 @@ static void matched(int f,struct sum_struct *s,struct map_struct *buf,
 }
 
 
-static inline char *window_ptr(struct map_struct *buf,int off,int len)
-{
-  static char *p=NULL;
-  static int p_len = 0;
-  static int p_off = 0;  
-
-  if (off == 0) {
-    p_off = 0;
-    p_len = CHUNK_SIZE;
-    p = map_ptr(buf,p_off,p_len);    
-  }
-
-  while (off+len > p_off+p_len) {
-    p_off += CHUNK_SIZE;
-    p_len = CHUNK_SIZE;
-    p = map_ptr(buf,p_off,p_len);  
-  }
-
-  return(p + (off-p_off));
-}
-
-
 static void hash_search(int f,struct sum_struct *s,
 			struct map_struct *buf,off_t len)
 {
@@ -159,7 +137,7 @@ static void hash_search(int f,struct sum_struct *s,
 
   k = MIN(len, s->n);
 
-  map = window_ptr(buf,0,k);
+  map = map_ptr(buf,0,k);
 
   sum = get_checksum1(map, k);
   s1 = sum & 0xFFFF;
@@ -197,7 +175,7 @@ static void hash_search(int f,struct sum_struct *s,
 
 	  if (!done_csum2) {
 	    int l = MIN(s->n,len-offset);
-	    map = window_ptr(buf,offset,l);
+	    map = map_ptr(buf,offset,l);
 	    get_checksum2(map,l,sum2);
 	    done_csum2 = 1;
 	  }
@@ -205,7 +183,7 @@ static void hash_search(int f,struct sum_struct *s,
 	    matched(f,s,buf,len,offset,i);
 	    offset += s->sums[i].len - 1;
 	    k = MIN((len-offset), s->n);
-	    map = window_ptr(buf,offset,k);
+	    map = map_ptr(buf,offset,k);
 	    sum = get_checksum1(map, k);
 	    s1 = sum & 0xFFFF;
 	    s2 = sum >> 16;
@@ -220,13 +198,13 @@ static void hash_search(int f,struct sum_struct *s,
     }
 
     /* Trim off the first byte from the checksum */
-    map = window_ptr(buf,offset,k+1);
-    s1 -= map[0];
-    s2 -= k * map[0];
+    map = map_ptr(buf,offset,k+1);
+    s1 -= map[0] + CHAR_OFFSET;
+    s2 -= k * (map[0]+CHAR_OFFSET);
 
     /* Add on the next byte (if there is one) to the checksum */
     if (k < (len-offset)) {
-      s1 += map[k];
+      s1 += (map[k]+CHAR_OFFSET);
       s2 += s1;
     } else {
       --k;
@@ -235,13 +213,13 @@ static void hash_search(int f,struct sum_struct *s,
   } while (++offset < end);
 
   matched(f,s,buf,len,len,-1);
-  window_ptr(buf,len-1,1);
+  map_ptr(buf,len-1,1);
 }
 
 
 void match_sums(int f,struct sum_struct *s,struct map_struct *buf,off_t len)
 {
-  char file_sum[SUM_LENGTH];
+  char file_sum[MD4_SUM_LENGTH];
 
   last_match = 0;
   false_alarms = 0;
@@ -270,7 +248,7 @@ void match_sums(int f,struct sum_struct *s,struct map_struct *buf,off_t len)
   if (remote_version >= 14) {
     if (verbose > 2)
       fprintf(FERROR,"sending file_sum\n");
-    write_buf(f,file_sum,SUM_LENGTH);
+    write_buf(f,file_sum,MD4_SUM_LENGTH);
   }
 
   if (targets) {
